@@ -890,6 +890,13 @@ impl_op_ex!(+ |a: &MetricNumber, b: &MetricNumber| -> MetricNumber {
     }
 });
 
+impl_op_ex!(+= |a: &mut MetricNumber, b: &MetricNumber| {
+    match a {
+        MetricNumber::Float(f) => *f += b.as_f64(),
+        MetricNumber::Int(i) => *i += b.as_i64().unwrap(),
+    }
+});
+
 impl_op_ex!(-|a: &MetricNumber, b: &MetricNumber| -> MetricNumber {
     match (a, b) {
         (MetricNumber::Float(f), MetricNumber::Float(f2)) => MetricNumber::Float(f - f2),
@@ -899,6 +906,13 @@ impl_op_ex!(-|a: &MetricNumber, b: &MetricNumber| -> MetricNumber {
     }
 });
 
+impl_op_ex!(-= |a: &mut MetricNumber, b: &MetricNumber| {
+    match a {
+        MetricNumber::Float(f) => *f -= b.as_f64(),
+        MetricNumber::Int(i) => *i -= b.as_i64().unwrap(),
+    }
+});
+
 impl_op_ex!(*|a: &MetricNumber, b: &MetricNumber| -> MetricNumber {
     match (a, b) {
         (MetricNumber::Float(f), MetricNumber::Float(f2)) => MetricNumber::Float(f * f2),
@@ -908,6 +922,13 @@ impl_op_ex!(*|a: &MetricNumber, b: &MetricNumber| -> MetricNumber {
     }
 });
 
+impl_op_ex!(*= |a: &mut MetricNumber, b: &MetricNumber| {
+    match a {
+        MetricNumber::Float(f) => *f *= b.as_f64(),
+        MetricNumber::Int(i) => *i *= b.as_i64().unwrap(),
+    }
+});
+
 impl_op_ex!(/ |a: &MetricNumber, b: &MetricNumber| -> MetricNumber {
     match (a, b) {
         (MetricNumber::Float(f), MetricNumber::Float(f2)) => MetricNumber::Float(f / f2),
@@ -917,6 +938,13 @@ impl_op_ex!(/ |a: &MetricNumber, b: &MetricNumber| -> MetricNumber {
     }
 });
 
+impl_op_ex!(/= |a: &mut MetricNumber, b: &MetricNumber| {
+    match a {
+        MetricNumber::Float(f) => *f /= b.as_f64(),
+        MetricNumber::Int(i) => *i /= b.as_i64().unwrap(),
+    }
+});
+
 #[derive(Debug)]
 pub enum ParseError {
     ParseError(String),
